==> predata-api-client-0.3.0.tar.gz: predata-api-client-0.3.0/predata/helpers/signal_client.py <==
from generic_client import PredataGenericClient


class PredataSignalClient(PredataGenericClient):

    """
    Client for requesting Predata signals.
    """

    def _handle_special_endpoints(self, endpoint, maximum, normalized):
        if maximum:
            endpoint += "max/"
        elif normalized:
            endpoint += "norm/"
        return endpoint

    def get_source_signal(self, source_id, signal_type="signals", date=None, maximum=False, normalized=False):
        """
        Get source signal by source id.

        Accepts difference signal type ("signals", "chatter", "contestation", "users")
        """
        endpoint = "data/source/%s/" % signal_type
        endpoint = self._handle_special_endpoints(endpoint, maximum, normalized) + "?source_id=%s" % (source_id)
        if date:
            endpoint += "&date=%s" % date.isoformat()
        return {
            "source": source_id,
            "signal_type": signal_type,
            "max": maximum,
            "normalized": normalized,
            "date": date,
            "result": self.make_request(endpoint)
        }

    def list_source_signal(self, source_id):
        """
        TODO: Return all signals associated with source

        i.e. for a given source, what set of chatter, contestation, user, signal is available
        in future, moving averages, transformations, etc.
        """
        raise NotImplementedError()

    def get_country_signal(self, country_code, date=None, maximum=False, normalized=False):
        """
        Get country signal by country code.
        """
        endpoint = "data/country/signals/"
        endpoint = self._handle_special_endpoints(endpoint, maximum, normalized) + "?iso3=%s" % country_code
        if date:
            endpoint += "&date=%s" % date.isoformat()
        return {
            "country": country_code,
            "max": maximum,
            "normalized": normalized,
            "date": date,
            "result": self.make_request(endpoint)
        }

    def list_country_signal(self, country_code):
        """
        TODO: Return all signals associated with country
        """
        raise NotImplementedError()

    def get_topic_signal(self, topic_id, date=None, maximum=False, normalized=False):
        """
        Get topic signal by topic_id.
        """
        endpoint = "data/topic/signals/"
        endpoint = self._handle_special_endpoints(endpoint, maximum, normalized) + "?topic_id=%s" % topic_id
        if date:
            endpoint += "&date=%s" % date.isoformat()
        return {
            "topic": topic_id,
            "max": maximum,
            "normalized": normalized,
            "date": date,
            "result": self.make_request(endpoint)
        }

    def list_topic_signals(self, topic_id):
        """
        TODO: Return all signals associated with topic
        """
        raise NotImplementedError()

    def get_asset_prices(self, asset_id):
        """
        Get asset signal / prices.
        """
        endpoint = "assets/prices/?asset_id=%s" % asset_id
        return {
            "asset_id": asset_id,
            "result": self.make_request(endpoint)
        }

==> predata-api-client-0.4.0.tar.gz: predata-api-client-0.4.0/predata/helpers/signal_client.py <==
from generic_client import PredataGenericClient


class PredataSignalClient(PredataGenericClient):

    """
    Client for requesting Predata signals.
    """

    def _handle_special_endpoints(self, endpoint, maximum, normalized):
        if maximum:
            endpoint += "max/"
        elif normalized:
            endpoint += "norm/"
        return endpoint

    def get_source_signal(self, source_id, signal_type="signals", date=None, maximum=False, normalized=False):
        """
        Get source signal by source id.

        Accepts difference signal type ("signals", "chatter", "contestation", "users")
        """
        endpoint = "signals/source/%s/" % signal_type
        endpoint = self._handle_special_endpoints(endpoint, maximum, normalized) + "?source_id=%s" % (source_id)
        if date:
            endpoint += "&date=%s" % date.isoformat()
        return {
            "source": source_id,
            "signal_type": signal_type,
            "max": maximum,
            "normalized": normalized,
            "date": date,
            "result": self.make_request(endpoint)
        }

    def list_source_signals(self, source_id):
        """
        Return all signals associated with source
        """
        endpoint = "data/sources/%s/" % source_id
        return {
            "source_id": source_id,
            "result": self.make_request(endpoint)["signal_types"]
        }

    def get_country_signal(self, country_code, date=None, maximum=False, normalized=False):
        """
        Get country signal by country code.
        """
        endpoint = "signals/country/overview/"
        endpoint = self._handle_special_endpoints(endpoint, maximum, normalized) + "?iso3=%s" % country_code
        if date:
            endpoint += "&date=%s" % date.isoformat()
        return {
            "country": country_code,
            "max": maximum,
            "normalized": normalized,
            "date": date,
            "result": self.make_request(endpoint)
        }

    def list_country_signals(self, country_code):
        """
        Return all signal types associated with country
        """
        endpoint = "data/countries/%s/" % country_code
        return {
            "country_code": country_code,
            "result": self.make_request(endpoint)["signal_types"]
        }

    def get_topic_signal(self, topic_id, date=None, maximum=False, normalized=False):
        """
        Get topic signal by topic_id.
        """
        endpoint = "signals/topic/overview/"
        endpoint = self._handle_special_endpoints(endpoint, maximum, normalized) + "?topic_id=%s" % topic_id
        if date:
            endpoint += "&date=%s" % date.isoformat()
        return {
            "topic": topic_id,
            "max": maximum,
            "normalized": normalized,
            "date": date,
            "result": self.make_request(endpoint)
        }

    def list_topic_signals(self, topic_id):
        """
        Return all signal types associated with topic
        """
        endpoint = "data/topics/%s/" % topic_id
        return {
            "topic_id": topic_id,
            "result": self.make_request(endpoint)["signal_types"]
        }

    def get_asset_prices(self, asset_id):
        """
        Get asset signal / prices.
        """
        endpoint = "data/assets/prices/?asset_id=%s" % asset_id
        return {
            "asset_id": asset_id,
            "result": self.make_request(endpoint)
        }
